@@ -130,6 +130,8 @@ fit_sae <- function(formula_fixed,
                 max_treedepth,
                 init)
 
+  data <- as.data.frame(data)
+
   # check scale_prior
   check_scale_prior(scale_prior)
 
@@ -162,13 +164,13 @@ fit_sae <- function(formula_fixed,
     y = data_obj$y_is,
     X = data_obj$X_scal[!data_obj$is_oos,],
     X_oos = data_obj$X_scal[data_obj$is_oos,],
-    M_is = data_obj$M,
+    M_is = data_obj$M_is,
     M_oos = length(data_obj$y[data_obj$is_oos]),
     P = ncol(data_obj$X_scal),
     disp = data_obj$dispersion,
     prior_coeff = ifelse(prior_coeff == "normal", 0, 1),
     indices_is = data_obj$indices_is,
-    indices_oos = data_obj$indices_oos,
+    indices_oos = as.array(data_obj$indices_oos),
     intercept = data_obj$intercept,
     sigma_unstr = scale_prior[["Unstructured"]],
     sigma_spatial = scale_prior[["Spatial"]],
